@@ -1,8 +1,9 @@
 import os, sys, cgi, re
 import gobject,gtk, gnome, gnome.ui, gnomevfs
-import deskbar, deskbar.Handler, deskbar.Utils
+import deskbar, deskbar.Handler, deskbar.Utils, deskbar.Match
 from gettext import gettext as _
 from os.path import exists
+from deskbar.defs import VERSION
 
 MAX_RESULTS = 20 # per handler
 
@@ -13,22 +14,39 @@ except:
 	# so do nothing now
 	pass
 
+def _show_start_beagle_dialog (dialog):
+	dialog = gtk.Dialog(_("Start Beagle Daemon?"), dialog,
+				gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT)
+	
+	dialog.set_default_size (350, 150)
+	dialog.add_button (_("Start Beagle Daemon"), gtk.RESPONSE_ACCEPT)
+	dialog.add_button (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT)
+	label = gtk.Label (_("The Beagle daemon does not appear to be running.\n You need to start it to use the Beagle Live handler."))
+	dialog.vbox.add (label)
+	label.show()
+
+	response = dialog.run()
+	dialog.destroy()
+	
+	
+	if response == gtk.RESPONSE_ACCEPT :
+		print "Starting Beagle Daemon."
+		gobject.spawn_async(["beagled"], flags=gobject.SPAWN_SEARCH_PATH)
+
+
 def _check_requirements():
+	# Check if we have python bindings for beagle
 	try:
 		import deskbar
 		import beagle
 	except Exception, e:
 		return (deskbar.Handler.HANDLER_IS_NOT_APPLICABLE, "Could not load beagle, libbeagle has been compiled without python bindings:"+str(e), None)
-	
-	try:	
-		client = beagle.Client()
-		request = beagle.DaemonInformationRequest()
-		response = client.send_request(request)
-		
+
+	# Check if beagled is running		
+	if not beagle.beagle_util_daemon_is_running () :
+		return (deskbar.Handler.HANDLER_HAS_REQUIREMENTS, "Beagle daemon is not running.", _show_start_beagle_dialog)
+	else:
 		return (deskbar.Handler.HANDLER_IS_HAPPY, None, None)
-	except Exception, e:
-		# FIXME: This string will need translation sooner or later
-		return (deskbar.Handler.HANDLER_HAS_REQUIREMENTS, "The beagle daemon isn't running.", None)
 	
 HANDLERS = {
 	"BeagleLiveHandler" : {
@@ -37,6 +55,7 @@ HANDLERS = {
 		# We must see how to detect properly beagle, for now it will fail on creating a new client
 		# when beagle is not available.
 		"requirements" : _check_requirements,
+		"version": VERSION,
 	}
 }
 
@@ -60,7 +79,7 @@ TYPES = {
 		"name"	: ("fixme:FileAs",),
 		"action": "evolution %(uri)s",
 		"icon"	: "stock_contact",
-		"description": _("Send Email to %s") % "<b>%(name)s</b>",
+		"description": _("Edit contact %s") % "<b>%(name)s</b>",
 		"category": "people",
 		},
 	
@@ -69,9 +88,8 @@ TYPES = {
 		"action": "evolution %(uri)s",
 		"icon"	: "stock_mail",
 		"extra": {"sender":("fixme:from_name", "parent:fixme:from_name")},
-		#translators: First %s is mail sender, second %s is mail subject.
-		"description": (_("Email from %s") % "<i>%(sender)s</i>" ) + "\n<b>%(name)s</b>",
-		"category": "documents",
+		"description": (_("From %s") % "<i>%(sender)s</i>" ) + "\n<b>%(name)s</b>",
+		"category": "emails",
 		},
 	"File" 		: {
 		"name"	: ("beagle:ExactFilename",), 
@@ -88,7 +106,7 @@ TYPES = {
 		"icon"	: "stock_news",
 		"description": (_("News from %s") % "<i>%(publisher)s</i>" ) + "\n<b>%(name)s</b>",
 		"snippet": True,
-		"category": "web",
+		"category": "news",
 		"extra": {"publisher":("dc:publisher",), "identifier": ("dc:identifier",)},
 		},
 	"Note"		: {
@@ -97,16 +115,16 @@ TYPES = {
 		"icon"	:"stock_notes",
 		"description": _("Note: %s") % "<b>%(name)s</b>",
 		"snippet": True,
-		"category": "documents",
+		"category": "notes",
 		},
 	"IMLog"		: {
 		"name"	: ("fixme:speakingto",),
 		"extra" : {"client": ("fixme:client",)},
-		"action": "beagle-imlogviewer --client %(client)s %(uri)s",
+		"action": "beagle-imlogviewer --client %(client)s --highlight-search '%(text)s' %(uri)s",
 		"icon"	: "im",
-		"description": _("Conversation with %s") % "<b>%(name)s</b>",
+		"description": _("With %s") % "<b>%(name)s</b>",
 		"snippet": True,
-		"category": "documents",
+		"category": "conversations",
 		},
 	"Calendar"	: {
 		"name"	: ("fixme:summary",),
@@ -119,7 +137,7 @@ TYPES = {
 		"name"	: ("dc:title",), # FIX-BEAGLE bug #330053, dc:title returns as None even though it _is_ set
 		"action": lambda d: gnome.url_show(d["uri"]),
 		"icon"	: "stock_bookmark",
-		"description": (_("Open History Item %s") % "<i>%(name)s</i>") + "\n%(uri)s",
+		"description": (_("Open History Item %s") % "<i>%(name)s</i>") + "\n%(escaped_uri)s",
 		"category": "web",
 		},
 }
@@ -147,7 +165,7 @@ class BeagleLiveMatch (deskbar.Match.Match):
 		action = TYPES[self.result["type"]]["action"]
 		if not callable(action) and action.startswith("beagle-imlogviewer"):
 			# Strip the uti descriptor, because imlogviewer takes a local path
-			self.result["uri"] = gnomevfs.get_local_path_from_uri(self.result["uri"])
+			self.result["uri"] = gnomevfs.get_local_path_from_uri(self.result["uri"])			
 		
 		# Load the correct icon
 		
@@ -175,6 +193,10 @@ class BeagleLiveMatch (deskbar.Match.Match):
 		
 	def get_name (self, text=None):
 		# We use the result dict itself to look up words
+		if text:
+			self.result["text"] = text
+			# Escape text since we use '%(text)s' as parameter
+			self.result["text"] = self.result["text"].replace("'", "\\'")
 		return self.result
 	
 	def get_verb(self):
@@ -182,6 +204,10 @@ class BeagleLiveMatch (deskbar.Match.Match):
 		return TYPES[self.result["type"]]["description"]
 		
 	def action(self, text=None):
+		# The call to get_name(text) ensures that we have
+		# the text field in the result dict
+		self.get_name(text)
+		
 		action = TYPES[self.result["type"]]["action"]
 		if callable(action):
 			print "BeagleLive url_show()", self.result
@@ -303,7 +329,11 @@ class BeagleLiveHandler(deskbar.Handler.SignallingHandler):
 							pass
 							
 					if val != None:
-						result[prop] = cgi.escape(val)
+						if prop == "uri" or prop == "identifier":
+							result[prop] = val
+							result["escaped_"+prop] = cgi.escape(val)
+						else:
+							result[prop] = cgi.escape(val)
 						break
 					
 				if val == None:
